@@ -158,22 +158,13 @@ class Homestuff{
 			if($stufftype == 'Default' && $nontrans_stufftitle != 'Home Page Dashboard' && $nontrans_stufftitle != 'Tag Cloud'){
 				if($modulename != 'NULL'){
 					if(isPermitted($modulename,'index') == "yes"){
-						$count_entries = $this->getDefaultDetails($stuffid,'calculateCnt');
-						if($count_entries > 0){
-							$homeval[]=Array('Stuffid'=>$stuffid,'Stufftype'=>$stufftype,'Stufftitle'=>$stuff_title);
-						}
-					}
-				}else{
-					$count_entries = $this->getDefaultDetails($stuffid,'calculateCnt');
-					if($count_entries > 0){
 						$homeval[]=Array('Stuffid'=>$stuffid,'Stufftype'=>$stufftype,'Stufftitle'=>$stuff_title);
 					}
-				}
-			}else if($stufftype == 'Tag Cloud'){
-				$freetag = new freetag();
-				if($freetag->get_tag_cloud_html("",$current_user->id) != ''){
+				}else{
 					$homeval[]=Array('Stuffid'=>$stuffid,'Stufftype'=>$stufftype,'Stufftitle'=>$stuff_title);
 				}
+			}else if($stufftype == 'Tag Cloud'){
+				$homeval[]=Array('Stuffid'=>$stuffid,'Stufftype'=>$stufftype,'Stufftitle'=>$stuff_title);
 			}else if($modulename != 'NULL'){
 				if(isPermitted($modulename,'index') == "yes"){
 					$homeval[]=Array('Stuffid'=>$stuffid,'Stufftype'=>$stufftype,'Stufftitle'=>$stuff_title);
@@ -237,11 +228,19 @@ class Homestuff{
 				$focus = CRMEntity::getInstance($modname);
 					
 				$oCustomView = new CustomView($modname);
-				$listquery = getListQuery($modname);
-				if(trim($listquery) == ''){
-					$listquery = $focus->getListQuery($modname);
+				$queryGenerator = new QueryGenerator($modname, $current_user);
+				$queryGenerator->initForCustomViewById($cvid);
+				$customViewFields = $queryGenerator->getCustomViewFields();
+				$fields = $queryGenerator->getFields();
+				$newFields = array_diff($fields, $customViewFields);
+
+				for($l=0;$l < $column_count;$l++){
+					$customViewColumnInfo = $adb->query_result($resultcvid,$l,"fieldname");
+					$details = explode(':', $customViewColumnInfo);
+					$newFields[] = $details[2];
 				}
-				$query = $oCustomView->getModifiedCvListQuery($cvid,$listquery,$modname);
+				$queryGenerator->setFields($newFields);
+				$query = $queryGenerator->getQuery();
 				$count_result = $adb->query(mkCountQuery($query));
 				$noofrows = $adb->query_result($count_result,0,"count");
 				$navigation_array = getNavigationValues(1, $noofrows, $maxval);
@@ -250,52 +249,31 @@ class Homestuff{
 				global $current_language,$app_strings;
 				$fieldmod_strings = return_module_language($current_language, $modname);
 				
-				if($modname == 'Calendar'){
-					$query .= "AND vtiger_activity.activitytype NOT IN ('Emails')";
-				}
-				
 				if( $adb->dbType == "pgsql"){
 					$list_result = $adb->query($query. " OFFSET 0 LIMIT ".$maxval);
 				}else{
 					$list_result = $adb->query($query. " LIMIT 0,".$maxval);
 				}
 				
-				for($l=0;$l < $column_count;$l++){
-					$fieldinfo = $adb->query_result($resultcvid,$l,"fieldname");
-					list($tabname,$colname,$fldname,$fieldmodlabel) = explode(":",$fieldinfo);
-					
-					$fieldheader=explode("_",$fieldmodlabel,2);
-					$fldlabel=$fieldheader[1];
-					$pos=strpos($fldlabel,"_");
-					if($pos==true){
-						$fldlabel=str_replace("_"," ",$fldlabel);
-					}
-					$field_label = isset($app_strings[$fldlabel])?$app_strings[$fldlabel]:(isset($fieldmod_strings[$fldlabel])?$fieldmod_strings[$fldlabel]:$fldlabel);
-					$cv_presence = $adb->pquery("SELECT * from vtiger_cvcolumnlist WHERE cvid = ? and columnname LIKE '%".$fldname."%'", array($cvid));
-					if($is_admin == false){
-						$fld_permission = getFieldVisibilityPermission($modname,$current_user->id,$fldname);
-					}
-					if($fld_permission == 0 && $adb->num_rows($cv_presence)){ 
-						$field_query = $adb->pquery("SELECT fieldlabel FROM vtiger_field WHERE fieldname = ? AND tablename = ? and vtiger_field.presence in (0,2)", array($fldname,$tabname));
-						$field_label = $adb->query_result($field_query,0,'fieldlabel');
-						$header[] = $field_label;
-					}
-					$fieldcolumns[$fldlabel] = Array($tabname=>$colname);
-				}
-				$listview_entries = getListViewEntries($focus,$modname,$list_result,$navigation_array,"","","EditView","Delete",$oCustomView,'HomePage',$fieldcolumns);
+				$controller = new ListViewController($adb, $current_user, $queryGenerator);
+				$controller->setHeaderSorting(false);
+				$header = $controller->getListViewHeader($focus,$modname,'','','', true);
+
+				$listview_entries = $controller->getListViewEntries($focus,$modname,$list_result,
+						$navigation_array, true);
 				$return_value =Array('ModuleName'=>$modname,'cvid'=>$cvid,'Maxentries'=>$maxval,'Header'=>$header,'Entries'=>$listview_entries);
 				if(sizeof($header)!=0){
 		       		return $return_value;
 				}else{
-		       		echo "Fields not found in Selected Filter";
+		       		return array('Entries'=>"Fields not found in Selected Filter");
 				}
 			}
 			else{
-				echo "<font color='red'>Filter You have Selected is Not Found</font>";
+				return array('Entries'=>"<font color='red'>Filter You have Selected is Not Found</font>");
 			}
  		}
 		else{
-			echo "<font color='red'>Permission Denied</font>";
+			return array('Entries'=>"<font color='red'>Permission Denied</font>");
 		}
 	}
 	
@@ -319,7 +297,7 @@ class Homestuff{
 			}
 			$return_value=Array('Maxentries'=>$maxval,'Entries'=>$rss_html);
 		}else{
-			echo "<font color='red'>Not Accessible</font>";
+			return array('Entries'=>"<font color='red'>Not Accessible</font>");
 		}
 		return $return_value;	
 	}
@@ -403,7 +381,7 @@ class Homestuff{
 				require_once('modules/PurchaseOrder/ListTopPurchaseOrder.php');
 				$home_values=getTopPurchaseOrder($maxval,$calCnt);
 			}	
-		}elseif($hometype=="LTFAQ" && vtlib_isModuleActive("FAQ")){
+		}elseif($hometype=="LTFAQ" && vtlib_isModuleActive("Faq")){
 			if(isPermitted('Faq','index') == "yes"){
 				require_once('modules/Faq/ListFaq.php');
 				$home_values=getMyFaq($maxval,$calCnt);
@@ -442,7 +420,7 @@ class Homestuff{
 		
 		$contents = "";
 		if($adb->num_rows($result)>0){
-			$contents = $adb->query_result($result,0,"contents");
+			$contents = vtlib_purify($adb->query_result($result,0,"contents"));
 		}
 		return $contents;
 	}
@@ -483,11 +461,12 @@ function getGroupTaskLists($maxval,$calCnt){
 		$query = '';
 		$params = array();
 		if(isPermitted('Leads','index') == "yes"){
-			$query = "select vtiger_leaddetails.leadid as id,vtiger_leaddetails.lastname as name,vtiger_groups.groupname as groupname, 'Leads     ' as Type from vtiger_leaddetails inner join vtiger_crmentity on vtiger_crmentity.crmid = vtiger_leaddetails.leadid inner join vtiger_groups on vtiger_crmentity.smownerid=vtiger_groups.groupid where  vtiger_crmentity.deleted=0";
+			$query = "select vtiger_leaddetails.leadid as id,vtiger_leaddetails.lastname as name,vtiger_groups.groupname as groupname, 'Leads     ' as Type from vtiger_leaddetails inner join vtiger_crmentity on vtiger_crmentity.crmid = vtiger_leaddetails.leadid inner join vtiger_groups on vtiger_crmentity.smownerid=vtiger_groups.groupid where vtiger_crmentity.deleted=0 and vtiger_leaddetails.leadid > 0";
 			if (count($groupids) > 0){
 				$query .= " and vtiger_groups.groupid in (". generateQuestionMarks($groupids). ")";
 				array_push($params, $groupids);
 			}
+			$query .= " LIMIT $maxval";
 		}
 		
 		if(vtlib_isModuleActive("Calendar") && isPermitted('Calendar','index') == "yes"){
@@ -495,11 +474,12 @@ function getGroupTaskLists($maxval,$calCnt){
 				$query .= " union all ";
 			}
 			//Get the activities assigned to group
-			$query .= "select vtiger_activity.activityid as id,vtiger_activity.subject as name,vtiger_groups.groupname as groupname,'Activities' as Type from vtiger_activity inner join vtiger_crmentity on vtiger_crmentity.crmid = vtiger_activity.activityid inner join vtiger_groups on vtiger_crmentity.smownerid=vtiger_groups.groupid where  vtiger_crmentity.deleted=0 and ((vtiger_activity.eventstatus !='held'and (vtiger_activity.status is null or vtiger_activity.status ='')) or (vtiger_activity.status !='completed' and (vtiger_activity.eventstatus is null or vtiger_activity.eventstatus='')))";
+			$query .= "select vtiger_activity.activityid as id,vtiger_activity.subject as name,vtiger_groups.groupname as groupname,'Activities' as Type from vtiger_activity inner join vtiger_crmentity on vtiger_crmentity.crmid = vtiger_activity.activityid inner join vtiger_groups on vtiger_crmentity.smownerid=vtiger_groups.groupid where  vtiger_crmentity.deleted=0 and ((vtiger_activity.eventstatus !='held'and (vtiger_activity.status is null or vtiger_activity.status ='')) or (vtiger_activity.status !='completed' and (vtiger_activity.eventstatus is null or vtiger_activity.eventstatus=''))) and vtiger_activity.activityid > 0";
 			if (count($groupids) > 0) {
 				$query .= " and vtiger_groups.groupid in (". generateQuestionMarks($groupids). ")";
 				array_push($params, $groupids);
 			}
+			$query .= " LIMIT $maxval";
 		}
 		
 		if(vtlib_isModuleActive("HelpDesk") && isPermitted('HelpDesk','index') == "yes"){
@@ -507,11 +487,12 @@ function getGroupTaskLists($maxval,$calCnt){
 				$query .= " union all ";
 			}
 			//Get the tickets assigned to group (status not Closed -- hardcoded value)
-			$query .= "select vtiger_troubletickets.ticketid,vtiger_troubletickets.title as name,vtiger_groups.groupname,'Tickets   ' as Type from vtiger_troubletickets inner join vtiger_crmentity on vtiger_crmentity.crmid = vtiger_troubletickets.ticketid inner join vtiger_groups on vtiger_crmentity.smownerid=vtiger_groups.groupid where vtiger_crmentity.deleted=0 and vtiger_troubletickets.status != 'Closed'";
+			$query .= "select vtiger_troubletickets.ticketid,vtiger_troubletickets.title as name,vtiger_groups.groupname,'Tickets   ' as Type from vtiger_troubletickets inner join vtiger_crmentity on vtiger_crmentity.crmid = vtiger_troubletickets.ticketid inner join vtiger_groups on vtiger_crmentity.smownerid=vtiger_groups.groupid where vtiger_crmentity.deleted=0 and vtiger_troubletickets.status != 'Closed' and vtiger_troubletickets.ticketid > 0";
 			if (count($groupids) > 0) {
 				$query .= " and vtiger_groups.groupid in (". generateQuestionMarks($groupids). ")";
 				array_push($params, $groupids);
 			}
+			$query .= " LIMIT $maxval";
 		}
 		
 		if(vtlib_isModuleActive("Potentials") && isPermitted('Potentials','index') == "yes"){
@@ -519,11 +500,12 @@ function getGroupTaskLists($maxval,$calCnt){
 				$query .=" union all ";
 			}	
 			//Get the potentials assigned to group(sales stage not Closed Lost or Closed Won-- hardcoded value)
-			$query .= "select vtiger_potential.potentialid,vtiger_potential.potentialname as name,vtiger_groups.groupname as groupname,'Potentials ' as Type from vtiger_potential  inner join vtiger_crmentity on vtiger_crmentity.crmid = vtiger_potential.potentialid inner join vtiger_groups on vtiger_crmentity.smownerid = vtiger_groups.groupid where vtiger_crmentity.deleted=0  and ((vtiger_potential.sales_stage !='Closed Lost') or (vtiger_potential.sales_stage != 'Closed Won'))";
+			$query .= "select vtiger_potential.potentialid,vtiger_potential.potentialname as name,vtiger_groups.groupname as groupname,'Potentials ' as Type from vtiger_potential  inner join vtiger_crmentity on vtiger_crmentity.crmid = vtiger_potential.potentialid inner join vtiger_groups on vtiger_crmentity.smownerid = vtiger_groups.groupid where vtiger_crmentity.deleted=0  and ((vtiger_potential.sales_stage !='Closed Lost') or (vtiger_potential.sales_stage != 'Closed Won')) and vtiger_potential.potentialid > 0";
 			if (count($groupids) > 0){
 				$query .= " and vtiger_groups.groupid in (". generateQuestionMarks($groupids). ")";
 				array_push($params, $groupids);
 			}
+			$query .= " LIMIT $maxval";
 		}
 		
 		if(vtlib_isModuleActive("Accounts") && isPermitted('Accounts','index') == "yes"){
@@ -531,8 +513,12 @@ function getGroupTaskLists($maxval,$calCnt){
 				$query .=" union all ";
 			}
 			//Get the Accounts assigned to group 
-			$query .= "select vtiger_account.accountid as id,vtiger_account.accountname as name,vtiger_groups.groupname as groupname, 'Accounts ' as Type from vtiger_account inner join vtiger_crmentity on vtiger_crmentity.crmid=vtiger_account.accountid inner join vtiger_groups on vtiger_crmentity.crmid=vtiger_groups.groupid where vtiger_crmentity.deleted=0 and vtiger_groups.groupid in(". generateQuestionMarks($groupids). ")"; 
-			array_push($params, $groupids);
+			$query .= "select vtiger_account.accountid as id,vtiger_account.accountname as name,vtiger_groups.groupname as groupname, 'Accounts ' as Type from vtiger_account inner join vtiger_crmentity on vtiger_crmentity.crmid=vtiger_account.accountid inner join vtiger_groups on vtiger_crmentity.smownerid=vtiger_groups.groupid where vtiger_crmentity.deleted=0 and vtiger_account.accountid > 0";
+			if (count($groupids) > 0){
+				$query .= " and vtiger_groups.groupid in (". generateQuestionMarks($groupids). ")";
+				array_push($params, $groupids);
+			}
+			$query .= " LIMIT $maxval";
 		}
 		
 		if(vtlib_isModuleActive("Contacts") && isPermitted('Contacts','index') =='yes'){
@@ -540,11 +526,12 @@ function getGroupTaskLists($maxval,$calCnt){
             	$query .=" union all ";
 			}
             //Get the Contacts assigned to group
-			$query .= "select vtiger_contactdetails.contactid as id, vtiger_contactdetails.lastname as name ,vtiger_groups.groupname as groupname, 'Contacts ' as Type from vtiger_contactdetails inner join vtiger_crmentity on vtiger_crmentity.crmid=vtiger_contactdetails.contactid inner join vtiger_groups on vtiger_crmentity.smownerid = vtiger_groups.groupid where vtiger_crmentity.deleted=0";
+			$query .= "select vtiger_contactdetails.contactid as id, vtiger_contactdetails.lastname as name ,vtiger_groups.groupname as groupname, 'Contacts ' as Type from vtiger_contactdetails inner join vtiger_crmentity on vtiger_crmentity.crmid=vtiger_contactdetails.contactid inner join vtiger_groups on vtiger_crmentity.smownerid = vtiger_groups.groupid where vtiger_crmentity.deleted=0 and vtiger_contactdetails.contactid > 0";
 			if (count($groupids) > 0) {
 				$query .= " and vtiger_groups.groupid in (". generateQuestionMarks($groupids). ")";
 				array_push($params, $groupids);
 			}
+			$query .= " LIMIT $maxval";
 		}
 		
 		if(vtlib_isModuleActive("Campaigns") && isPermitted('Campaigns','index') =='yes'){
@@ -552,11 +539,12 @@ function getGroupTaskLists($maxval,$calCnt){
 				$query .=" union all ";
 			}
 			//Get the Campaigns assigned to group(Campaign status not Complete -- hardcoded value)
-			$query .= "select vtiger_campaign.campaignid as id, vtiger_campaign.campaignname as name, vtiger_groups.groupname as groupname,'Campaigns ' as Type from vtiger_campaign inner join  vtiger_crmentity on vtiger_crmentity.crmid = vtiger_campaign.campaignid inner join vtiger_groups on vtiger_crmentity.smownerid = vtiger_groups.groupid where vtiger_crmentity.deleted=0  and (vtiger_campaign.campaignstatus != 'Complete')";
+			$query .= "select vtiger_campaign.campaignid as id, vtiger_campaign.campaignname as name, vtiger_groups.groupname as groupname,'Campaigns ' as Type from vtiger_campaign inner join  vtiger_crmentity on vtiger_crmentity.crmid = vtiger_campaign.campaignid inner join vtiger_groups on vtiger_crmentity.smownerid = vtiger_groups.groupid where vtiger_crmentity.deleted=0  and (vtiger_campaign.campaignstatus != 'Complete') and vtiger_campaign.campaignid > 0";
 			if (count($groupids) > 0) {
 				$query .= " and vtiger_groups.groupid in (". generateQuestionMarks($groupids). ")";
 				array_push($params, $groupids);
 			}
+			$query .= " LIMIT $maxval";
 		}
 		
 		if(vtlib_isModuleActive("Quotes") && isPermitted('Quotes','index') == 'yes'){
@@ -564,11 +552,12 @@ function getGroupTaskLists($maxval,$calCnt){
 				$query .=" union all ";
 			}
 			//Get the Quotes assigned to group(Quotes stage not Rejected -- hardcoded value)
-			$query .="select vtiger_quotes.quoteid as id,vtiger_quotes.subject as name, vtiger_groups.groupname as groupname ,'Quotes 'as Type from vtiger_quotes inner join vtiger_crmentity on vtiger_crmentity.crmid = vtiger_quotes.quoteid inner join vtiger_groups on vtiger_crmentity.smownerid = vtiger_groups.groupid where vtiger_crmentity.deleted=0  and (vtiger_quotes.quotestage != 'Rejected')";
+			$query .="select vtiger_quotes.quoteid as id,vtiger_quotes.subject as name, vtiger_groups.groupname as groupname ,'Quotes 'as Type from vtiger_quotes inner join vtiger_crmentity on vtiger_crmentity.crmid = vtiger_quotes.quoteid inner join vtiger_groups on vtiger_crmentity.smownerid = vtiger_groups.groupid where vtiger_crmentity.deleted=0  and (vtiger_quotes.quotestage != 'Rejected') and vtiger_quotes.quoteid > 0";
 			if (count($groupids) > 0) {
 				$query .= " and vtiger_groups.groupid in (". generateQuestionMarks($groupids). ")";
 				array_push($params, $groupids);
 			}
+			$query .= " LIMIT $maxval";
 		}
 		
 		if(vtlib_isModuleActive("SalesOrder") && isPermitted('SalesOrder','index') =='yes'){
@@ -576,8 +565,12 @@ function getGroupTaskLists($maxval,$calCnt){
 				$query .=" union all ";
 			}
             //Get the Sales Order assigned to group
-            $query .="select vtiger_salesorder.salesorderid as id, vtiger_salesorder.subject as name,vtiger_groups.groupname as groupname,'SalesOrder ' as Type from vtiger_salesorder inner join vtiger_crmentity on vtiger_crmentity.crmid = vtiger_salesorder.salesorderid inner join vtiger_groups on vtiger_crmentity.smownerid = vtiger_groups.groupid where vtiger_crmentity.deleted=0 and vtiger_groups.groupid in  (". generateQuestionMarks($groupids). ")";
-			array_push($params, $groupids);
+            $query .="select vtiger_salesorder.salesorderid as id, vtiger_salesorder.subject as name,vtiger_groups.groupname as groupname,'SalesOrder ' as Type from vtiger_salesorder inner join vtiger_crmentity on vtiger_crmentity.crmid = vtiger_salesorder.salesorderid inner join vtiger_groups on vtiger_crmentity.smownerid = vtiger_groups.groupid where vtiger_crmentity.deleted=0 and vtiger_salesorder.salesorderid > 0";
+			if (count($groupids) > 0){
+				$query .= " and vtiger_groups.groupid in (". generateQuestionMarks($groupids). ")";
+				array_push($params, $groupids);
+			}
+			$query .= " LIMIT $maxval";
 		}	
 		
 		if(vtlib_isModuleActive("Invoice") && isPermitted('Invoice','index') =='yes'){
@@ -585,8 +578,12 @@ function getGroupTaskLists($maxval,$calCnt){
 				$query .=" union all ";
 			}
 			//Get the Sales Order assigned to group(Invoice status not Paid -- hardcoded value)
-			$query .="select vtiger_invoice.invoiceid as Id , vtiger_invoice.subject as Name, vtiger_groups.groupname as groupname,'Invoice ' as Type from vtiger_invoice inner join vtiger_crmentity on vtiger_crmentity.crmid = vtiger_invoice.invoiceid inner join vtiger_groups on vtiger_crmentity.smownerid = vtiger_groups.groupid where vtiger_crmentity.deleted=0 and(vtiger_invoice.invoicestatus != 'Paid') and vtiger_groups.groupid in  (". generateQuestionMarks($groupids). ")";
-			array_push($params, $groupids);
+			$query .="select vtiger_invoice.invoiceid as Id , vtiger_invoice.subject as Name, vtiger_groups.groupname as groupname,'Invoice ' as Type from vtiger_invoice inner join vtiger_crmentity on vtiger_crmentity.crmid = vtiger_invoice.invoiceid inner join vtiger_groups on vtiger_crmentity.smownerid = vtiger_groups.groupid where vtiger_crmentity.deleted=0 and(vtiger_invoice.invoicestatus != 'Paid') and vtiger_invoice.invoiceid > 0";
+			if (count($groupids) > 0){
+				$query .= " and vtiger_groups.groupid in (". generateQuestionMarks($groupids). ")";
+				array_push($params, $groupids);
+			}
+			$query .= " LIMIT $maxval";
 		}
 		
 		if(vtlib_isModuleActive("PurchaseOrder") && isPermitted('PurchaseOrder','index') == 'yes'){
@@ -594,11 +591,12 @@ function getGroupTaskLists($maxval,$calCnt){
 				$query .=" union all ";
 			}
 			//Get the Purchase Order assigned to group
-			$query .="select vtiger_purchaseorder.purchaseorderid as id,vtiger_purchaseorder.subject as name,vtiger_groups.groupname as groupname, 'PurchaseOrder ' as Type from vtiger_purchaseorder inner join vtiger_crmentity on vtiger_crmentity.crmid = vtiger_purchaseorder.purchaseorderid inner join  vtiger_groups on vtiger_crmentity.smownerid =vtiger_groups.groupid where vtiger_crmentity.deleted=0";
+			$query .="select vtiger_purchaseorder.purchaseorderid as id,vtiger_purchaseorder.subject as name,vtiger_groups.groupname as groupname, 'PurchaseOrder ' as Type from vtiger_purchaseorder inner join vtiger_crmentity on vtiger_crmentity.crmid = vtiger_purchaseorder.purchaseorderid inner join  vtiger_groups on vtiger_crmentity.smownerid =vtiger_groups.groupid where vtiger_crmentity.deleted=0 and vtiger_purchaseorder.purchaseorderid >0";
 			if (count($groupids) > 0) {
 				$query .= " and vtiger_groups.groupid in (". generateQuestionMarks($groupids). ")";
 				array_push($params, $groupids);
 			}
+			$query .= " LIMIT $maxval";
 		}
 		
 		if(vtlib_isModuleActive("Documents") && isPermitted('Documents','index') == 'yes'){
@@ -606,14 +604,14 @@ function getGroupTaskLists($maxval,$calCnt){
 				$query .=" union all ";
 			}
 			//Get the Purchase Order assigned to group
-			$query .="select vtiger_notes.notesid as id,vtiger_notes.title as name,vtiger_groups.groupname as groupname, 'Documents' as Type from vtiger_notes inner join vtiger_crmentity on vtiger_crmentity.crmid = vtiger_notes.notesid inner join  vtiger_groups on vtiger_crmentity.smownerid =vtiger_groups.groupid where vtiger_crmentity.deleted=0";
+			$query .="select vtiger_notes.notesid as id,vtiger_notes.title as name,vtiger_groups.groupname as groupname, 'Documents' as Type from vtiger_notes inner join vtiger_crmentity on vtiger_crmentity.crmid = vtiger_notes.notesid inner join  vtiger_groups on vtiger_crmentity.smownerid =vtiger_groups.groupid where vtiger_crmentity.deleted=0 and vtiger_notes.notesid > 0";
 			if (count($groupids) > 0) {
 				$query .= " and vtiger_groups.groupid in (". generateQuestionMarks($groupids). ")";
 				array_push($params, $groupids);
 			}
+			$query .= " LIMIT $maxval";
 		}
 		
-		$query .= " LIMIT 0, $maxval";
 		$log->info("Here is the where clause for the list view: $query");
 		$result = $adb->pquery($query, $params) or die("Couldn't get the group listing");
 
