@@ -165,7 +165,7 @@
 				/*For global add/delete in picklist*/
 				LBL_GIVE_PICKLIST_VALUE:'Please provide some value for the selected picklist to be replaced',
 				LBL_SELECT_ROLE:'Please select atleast one role for which the new values are to be added',
-				LBL_ADD_PICKLIST_VALUE:'Please provide atleast one new value to be added',
+				LBL_ADD_PICKLIST_VALUE:'Please provide at least one new value to be added',
 				LBL_NO_VALUES_TO_DELETE: "no values to delete",
 
                 /* For Duplicate merging feature */
@@ -293,5 +293,14 @@
 				RSS: 'RSS',
 				Default: 'Default',
 				Notebook: 'Notebook',
-				SPECIAL_CHARS:'\\ / < > + \' " '
+				SPECIAL_CHARS:'\\ / < > + \' " ',
+				
+				BETWEEN: 'between',
+				BEFORE: 'before',
+				AFTER: 'after',
+				'ERROR_DELETING_TRY_AGAIN': 'Error while deleting.Please try again.',
+				'LBL_ENTER_WINDOW_TITLE': 'Please enter Window Title.',
+				'LBL_SELECT_ONLY_FIELDS': 'Please select only two fields.',
+				'LBL_ENTER_RSS_URL':'Please enter RSS URL',
+				'LBL_ADD_HOME_WIDGET': 'Unable to add homestuff! Please try again'
 			};
