@@ -30,7 +30,7 @@ $table_col_array=array('vtiger_account.accountname','vtiger_contactdetails.first
 function getSearchListHeaderValues($focus, $module,$sort_qry='',$sorder='',$order_by='',$relatedlist='',$oCv='')
 {
 	global $log;
-	$log->debug("Entering getSearchListHeaderValues(".get_class($focus).",". $module.",".$sort_qry.",".$sorder.",".$order_by.",".$relatedlist.",".get_class($oCv).") method ...");
+	$log->debug("Entering getSearchListHeaderValues(".(is_object($focus)? get_class($focus):'').",". $module.",".$sort_qry.",".$sorder.",".$order_by.",".$relatedlist.",".(is_object($oCV)? get_class($oCV):'').") method ...");
         global $adb;
         global $theme;
         global $app_strings;
@@ -218,30 +218,10 @@ function get_usersid($table_name,$column_name,$search_string)
 {
 
 	global $log;
-        $log->debug("Entering get_usersid(".$table_name.",".$column_name.",".$search_string.") method ...");
+	$log->debug("Entering get_usersid(".$table_name.",".$column_name.",".$search_string.") method ...");
 	global $adb;
-	$user_qry="select distinct(vtiger_users.id)from vtiger_users inner join vtiger_crmentity on vtiger_crmentity.smownerid=vtiger_users.id where vtiger_users.user_name like '" . formatForSqlLike($search_string) . "'";
-	$user_result=$adb->pquery($user_qry, array());
-	$noofuser_rows=$adb->num_rows($user_result);
-	$x=$noofuser_rows-1;
-	if($noofuser_rows!=0)
-	{
-		$where="(";
-		for($i=0;$i<$noofuser_rows;$i++)
-		{
-			$user_id=$adb->query_result($user_result,$i,'id');
-			$where .= "$table_name.$column_name =".$user_id;
-			if($i != $x)
-			{
-				$where .= " or ";
-			}
-		}
-		$where.=" or vtiger_groups.groupname like '". formatForSqlLike($search_string) ."')";
-	}
-	else
-	{
-		$where=" vtiger_groups.groupname like '". formatForSqlLike($search_string) ."' ";
-	}	
+	$where.="(vtiger_users.user_name like '". formatForSqlLike($search_string) .
+			"' or vtiger_groups.groupname like '". formatForSqlLike($search_string) ."')";
 	$log->debug("Exiting get_usersid method ...");
 	return $where;	
 }
@@ -431,7 +411,7 @@ function BasicSearch($module,$search_field,$search_string){
 							if ($stridx !== 0) 
 							{
 								$search_string = $mod_key;
-								if(getFieldVisibilityPermission("Calendar", $current_user->id,'taskstatus') == '0' && ($tab_col == "vtiger_activity.status" || $tab_col == "vtiger_activity.eventstatus"))
+								if(getFieldVisibilityPermission("Calendar", $current_user->id,'taskstatus') == '0' && ($column_name == "status" || $column_name == "eventstatus"))
 								{
 										$where="(vtiger_activity.status like '". formatForSqlLike($search_string) ."' or vtiger_activity.eventstatus like '". formatForSqlLike($search_string) ."')";
 								}
@@ -707,7 +687,17 @@ function getcriteria_options()
 {
 	global $log,$app_strings;
 	$log->debug("Entering getcriteria_options() method ...");
-	$CRIT_OPT = "<option value=\'cts\'>".str_replace("'","`",$app_strings['contains'])."</option><option value=\'dcts\'>".str_replace("'","`",$app_strings['does_not_contains'])."</option><option value=\'is\'>".str_replace("'","`",$app_strings['is'])."</option><option value=\'isn\'>".str_replace("'","`",$app_strings['is_not'])."</option><option value=\'bwt\'>".str_replace("'","`",$app_strings['begins_with'])."</option><option value=\'ewt\'>".str_replace("'","`",$app_strings['ends_with'])."</option><option value=\'grt\'>".str_replace("'","`",$app_strings['greater_than'])."</option><option value=\'lst\'>".str_replace("'","`",$app_strings['less_than'])."</option><option value=\'grteq\'>".str_replace("'","`",$app_strings['greater_or_equal'])."</option><option value=\'lsteq\'>".str_replace("'","`",$app_strings['less_or_equal'])."</option>";
+	$CRIT_OPT = "<option value=\'c\'>".str_replace("'","`",$app_strings['contains']).
+			"</option><option value=\'k\'>".str_replace("'","`",$app_strings['does_not_contains']).
+			"</option><option value=\'e\'>".str_replace("'","`",$app_strings['is']).
+			"</option><option value=\'n\'>".str_replace("'","`",$app_strings['is_not']).
+			"</option><option value=\'s\'>".str_replace("'","`",$app_strings['begins_with']).
+			"</option><option value=\'ew\'>".str_replace("'","`",$app_strings['ends_with']).
+			"</option><option value=\'g\'>".str_replace("'","`",$app_strings['greater_than']).
+			"</option><option value=\'l\'>".str_replace("'","`",$app_strings['less_than']).
+			"</option><option value=\'h\'>".str_replace("'","`",$app_strings['greater_or_equal']).
+			"</option><option value=\'m\'>".str_replace("'","`",$app_strings['less_or_equal']).
+			"</option>";
 	$log->debug("Exiting getcriteria_options method ...");
 	return $CRIT_OPT;
 }
@@ -942,6 +932,92 @@ function getWhereCondition($currentModule)
 
 }
 
+function getSearchURL($input) {
+	global $log,$default_charset;
+	$urlString='';
+	if($input['searchtype']=='advance') {
+		if(empty($input['search_cnt'])) {
+			return $urlString;
+		}
+		$noOfConditions = vtlib_purify($input['search_cnt']);
+		for($i=0; $i<$noOfConditions; $i++) {
+			$fieldInfo = 'Fields'.$i;
+			$condition = 'Condition'.$i;
+			$value = 'Srch_value'.$i;
+
+			list($fieldName,$typeOfData) = split("::::",str_replace('\'','',
+					stripslashes($input[$fieldInfo])));
+			$operator = str_replace('\'','',stripslashes($input[$condition]));
+			$searchValue = $input[$value];
+			$searchValue = function_exists(iconv) ? @iconv("UTF-8",$default_charset,
+					$searchValue) : $searchValue;
+			$urlString .="&Fields$i=$fieldName&Condition$i=$operator&Srch_value$i=".
+					urlencode($searchValue);
+		}
+		$urlString .= "&searchtype=advance&search_cnt=$noOfConditions&matchtype=".
+				vtlib_purify($input['matchtype']);
+	} elseif($input['type']=='dbrd'){
+		if(isset($input['leadsource'])) {
+			$leadSource = $input['leadsource'];
+			$urlString .= "&leadsource=".$leadSource;
+		}
+		if(isset($input['date_closed'])) {
+			$dateClosed = $input['date_closed'];
+			$urlString .= "&date_closed=".$dateClosed;
+		}
+		if(isset($input['sales_stage'])) {
+			$salesStage = $input['sales_stage'];
+			$urlString .= "&sales_stage=".$salesStage;
+		}
+		if(!empty($input['closingdate_start']) && !empty($input['closingdate_end'])) {
+			$dateClosedStart = $input['closingdate_start'];
+			$dateClosedEnd = $input['closingdate_end'];
+			$urlString .= "&closingdate_start=$dateClosedStart&closingdate_end=".$dateClosedEnd;
+		}
+		if(isset($input['owner'])) {
+			$owner = vtlib_purify($input['owner']);
+			$urlString .= "&owner=".$owner;
+		}
+		if(isset($input['campaignid'])) {
+			$campaignId = vtlib_purify($input['campaignid']);
+			$urlString .= "&campaignid=".$campaignId;
+		}
+		if(isset($input['quoteid'])) {
+			$quoteId = vtlib_purify($input['quoteid']);
+			$urlString .= "&quoteid=".$quoteId;
+		}
+		if(isset($input['invoiceid'])) {
+			$invoiceId = vtlib_purify($input['invoiceid']);
+			$urlString .= "&invoiceid=".$invoiceId;
+		}
+		if(isset($input['purchaseorderid'])) {
+			$purchaseOrderId = vtlib_purify($input['purchaseorderid']);
+			$urlString .= "&purchaseorderid=".$purchaseOrderId;
+		}
+
+		if(isset($input['from_homepagedb']) && $input['from_homepagedb'] != '') {
+			$url_string .= "&from_homepagedb=".vtlib_purify($input['from_homepagedb']);
+		}
+		if(isset($input['type']) && $input['type'] != '') {
+			$url_string .= "&type=".vtlib_purify($input['type']);
+		}
+	} else {
+		$value = $input['search_text'];
+		$stringConvert = function_exists(iconv) ? @iconv("UTF-8",$default_charset,$value) : 
+				$value;
+		$value=trim($stringConvert);
+		$field=vtlib_purify($input['search_field']);
+ 		$urlString = "&search_field=$field&search_text=".urlencode($value)."&searchtype=BasicSearch";
+		if(!empty($input['type'])) {
+			$urlString .= "&type=".vtlib_purify($input['type']);
+		}
+		if(!empty($input['operator'])) {
+			$urlString .= "&operator=".$input['operator'];
+		}
+	}
+	return $urlString;
+}
+
 /**This function is returns the where conditions for dashboard and shows the records when clicked on dashboard graph
 *Takes no parameter, process the values got from the html request object
 *Returns the search criteria option (where condition) to be added in list query
