@@ -10,7 +10,7 @@
  * Read the entire license text here: http://www.gnu.org/licenses/lgpl.html
  */
 
-// $Id: calendar.js 9623 2006-10-10 16:02:43Z richie $
+// $Id: calendar.js 11471 2007-10-15 12:18:52Z mangai $
 
 /** The Calendar object constructor. */
 Calendar = function (firstDayOfWeek, dateStr, onSelected, onClose) {
@@ -1293,7 +1293,7 @@ Calendar.prototype.showAt = function (x, y) {
 Calendar.prototype.showAtElement = function (el, opts) {
 	var self = this;
 	var p = Calendar.getAbsolutePos(el);
-	if (!opts || typeof opts != "string") {
+	if (!opts || opts == "Br" || typeof opts != "string") {
 		this.showAt(p.x, p.y + el.offsetHeight);
 		return true;
 	}
