@@ -52,5 +52,7 @@ if($ajaxaction == "DETAILVIEW")
 	{
 		echo ":#:FAILURE";
 	}
+}elseif($ajaxaction == "LOADRELATEDLIST" || $ajaxaction == "DISABLEMODULE"){
+	require_once 'include/ListView/RelatedListViewContents.php';
 }
 ?>
\ No newline at end of file
