@@ -18,14 +18,14 @@
  * defined return URL.
  ********************************************************************************/
 
-require_once('modules/HelpDesk/HelpDesk.php');
+global $currentModule;
+$focus = CRMEntity::getInstance($currentModule);
+
 global $mod_strings;
 
 require_once('include/logging.php');
 $log = LoggerManager::getLogger('ticket_delete');
 
-$focus = new HelpDesk();
-
 //Added to fix 4600
 $url = getBasic_Advance_SearchURL();
 
@@ -34,8 +34,8 @@ if(!isset($_REQUEST['record']))
 
 DeleteEntity($_REQUEST['module'],$_REQUEST['return_module'],$focus,$_REQUEST['record'],$_REQUEST['return_id']);
 
-if(isset($_REQUEST['parenttab']) && $_REQUEST['parenttab'] != "") $parenttab = $_REQUEST['parenttab'];
+$parenttab = getParentTab();
 
-header("Location: index.php?module=".$_REQUEST['return_module']."&action=".$_REQUEST['return_action']."&parenttab=".$parenttab."&record=".$_REQUEST['return_id']."&relmodule=".$_REQUEST['module'].$url);
+header("Location: index.php?module=".vtlib_purify($_REQUEST['return_module'])."&action=".vtlib_purify($_REQUEST['return_action'])."&parenttab=$parenttab&record=".vtlib_purify($_REQUEST['return_id'])."&relmodule=".vtlib_purify($_REQUEST['module']).$url);
 
-?>
+?>
\ No newline at end of file
