@@ -1,12 +1,11 @@
 <?php
-/*********************************************************************************
-** The contents of this file are subject to the vtiger CRM Public License Version 1.0
+/*+********************************************************************************
+ * The contents of this file are subject to the vtiger CRM Public License Version 1.0
  * ("License"); You may not use this file except in compliance with the License
  * The Original Code is:  vtiger CRM Open Source
  * The Initial Developer of the Original Code is vtiger.
  * Portions created by vtiger are Copyright (C) vtiger.
  * All Rights Reserved.
-*
  ********************************************************************************/
 
 global $current_user;
@@ -133,12 +132,6 @@ if($_REQUEST['migration_option'] != '')
 	}
 }
 
-//For 5.0.2 we have added this table. After 5.0.2 we have to remove this and provide the migration in some other way
-/*$res = $adb->query("show create table vtiger_entityname");
-if(!$res)
-	$smarty->assign("502_PATCH","apply");*/
-
 $smarty->display("MigrationStep1.tpl");
 
-
-?>
+?>
\ No newline at end of file
