@@ -11,12 +11,21 @@
 
 require_once('modules/Portal/Portal.php');
 
-global $default_charset;
+global $default_charset,$adb;
 $conv_pname = function_exists(iconv) ? @iconv("UTF-8",$default_charset, $_REQUEST['portalname']) : $_REQUEST['portalname'];
 $conv_purl = function_exists(iconv) ? @iconv("UTF-8",$default_charset, $_REQUEST['portalurl']) : $_REQUEST['portalurl'];
-$portlname =str_replace(array("'",'"'),'',$conv_pname);
 $portlurl =str_replace(array("'",'"'),'',$conv_purl);
-
+$portlname = from_html($conv_pname);
+$portlurl = from_html($portlurl);
+//added as an enhancement to set default value
+if(isset($_REQUEST['check']) && $_REQUEST['check'] =='true')
+{
+	$updateDefalt ="UPDATE vtiger_portal SET setdefault=1 WHERE portalid=?";
+	$set_def = $adb->pquery($updateDefalt, array($_REQUEST['passing_var']));
+	$updateZero = "UPDATE vtiger_portal SET setdefault=0 WHERE portalid not in(?)";
+	$set_default= $adb->pquery($updateZero, array($_REQUEST['passing_var']));
+	exit();
+}	
 if($portlname != '' && $portlurl != '')
 {
 	if(isset($_REQUEST['record']) && $_REQUEST['record'] !='')
