@@ -26,5 +26,9 @@ $mod_strings = Array(
 'LBL_TOOLS'=>'Tools',
 'LBL_MANAGE_SITES'=>'Manage Sites',
 'LBL_MY_SITES'=>'Sites',
+
+// Added/Updated for vtiger CRM 5.0.4
+//added as an enhancement
+'LBL_SET_DEFAULT_BUTTON'=>'Set As Default',
 );
 ?>
