@@ -42,7 +42,7 @@ function getTopPotentials($maxval,$calCnt)
 	$title[]='myTopOpenPotentials.gif';
 	$title[]=$current_module_strings['LBL_TOP_OPPORTUNITIES'];
 	$title[]='home_mypot';
-	$where = "AND vtiger_potential.sales_stage not in ('Closed Won','Closed Lost','".$current_module_strings['Closed Won']."','".$current_module_strings['Closed Lost']."') AND vtiger_crmentity.smownerid='".$current_user->id."'";
+	$where = "AND vtiger_potential.potentialid > 0 AND vtiger_potential.sales_stage not in ('Closed Won','Closed Lost','".$current_module_strings['Closed Won']."','".$current_module_strings['Closed Lost']."') AND vtiger_crmentity.smownerid='".$current_user->id."' AND vtiger_potential.amount > 0";
 	$header=array();
 	$header[]=$current_module_strings['LBL_LIST_OPPORTUNITY_NAME'];
 	//$header[]=$current_module_strings['LBL_LIST_ACCOUNT_NAME'];
@@ -51,7 +51,13 @@ function getTopPotentials($maxval,$calCnt)
 	$rate = $rate_symbol['rate'];
 	$curr_symbol = $rate_symbol['symbol'];
         $header[]=$current_module_strings['LBL_LIST_AMOUNT'].'('.$curr_symbol.')';
-	$list_query = getListQuery("Potentials",$where);
+	$list_query = "SELECT vtiger_crmentity.crmid, vtiger_potential.potentialname,
+			vtiger_potential.amount, potentialid
+			FROM vtiger_potential
+			IGNORE INDEX(PRIMARY) INNER JOIN vtiger_crmentity
+				ON vtiger_crmentity.crmid = vtiger_potential.potentialid";
+	$list_query .= getNonAdminAccessControlQuery('Potentials',$current_user);
+	$list_query .= "WHERE vtiger_crmentity.deleted = 0 ".$where;
 	$list_query .=" ORDER BY amount DESC";
 	
 	$list_query .=" LIMIT " . $adb->sql_escape_string($maxval);
@@ -85,7 +91,7 @@ function getTopPotentials($maxval,$calCnt)
 		}
 	}
 	
-	$search_qry = "&query=true&Fields0=vtiger_crmentity.smownerid&Condition0=is&Srch_value0=".$current_user->column_fields['user_name']."&Fields1=vtiger_potential.sales_stage&Condition1=dcts&Srch_value1=closed&searchtype=advance&search_cnt=2&matchtype=all";
+	$search_qry = "&query=true&Fields0=assigned_user_id&Condition0=e&Srch_value0=".$current_user->column_fields['user_name']."&Fields1=sales_stage&Condition1=k&Srch_value1=closed&searchtype=advance&search_cnt=2&matchtype=all";
 			
 	$values=Array('ModuleName'=>'Potentials','Title'=>$title,'Header'=>$header,'Entries'=>$entries,'search_qry'=>$search_qry);
 
