@@ -29,5 +29,6 @@ else
 	$adb->pquery($query, array($record, $return_id)); 
 }
 
-header("Location: index.php?module=".$return_module."&action=".$return_module."Ajax&file=$return_action&ajax=delpbprorel&record=".$return_id);
+header("Location: index.php?module=".$return_module."&action=".$return_module.
+		"Ajax&file=$return_action&ajax=true&record=".$return_id);
 ?>
\ No newline at end of file
