@@ -182,7 +182,7 @@ $mod_strings = Array(
 'Box'=>'Box',
 'Carton'=>'Carton',
 'Caton'=>'Caton',
-'Dozen'=>'Dazon',
+'Dozen'=>'Dozen',
 'Each'=>'Each',
 'Hours'=>'Hours',
 'Impressions'=>'Impressions',
