@@ -8,12 +8,11 @@
  * All Rights Reserved.
  *
  ********************************************************************************/
+include_once 'modules/SalesOrder/SalesOrderPDFController.php';
 
+$controller = new Vtiger_SalesOrderPDFController($currentModule);
+$controller->loadRecord(vtlib_purify($_REQUEST['record']));
 
-include('include/InventoryPDF.php');
-$pdf=get_so_pdf();
-
-$pdf->Output('SalesOrder.pdf','D'); //added file name to make it work in IE, also forces the download giving the user the option to save
-
+$controller->Output('SalesOrder.pdf', 'D');//added file name to make it work in IE, also forces the download giving the user the option to save
 exit();
 ?>
