@@ -185,6 +185,11 @@ $mod_strings = Array(
 'Cancelled'=>'Cancelled',
 'Adjustment'=>'Adjustment',
 'Sub Total'=>'Sub Total',
+'AutoCreated'=>'AutoCreated',
+'Sent'=>'Sent',
+'Credit Invoice'=>'Credit Invoice',
+'Paid'=>'Paid',
+
 
 //Added for Reports (5.0.4)
 'Tax Type'=>'Tax Type',
@@ -192,6 +197,18 @@ $mod_strings = Array(
 'Discount Amount'=>'Discount Amount',
 'Terms & Conditions'=>'Terms & Conditions',
 'S&H Amount'=>'S&H Amount',
+
+//Added after 5.0.4 GA
+'SalesOrder No'=>'SalesOrder No',
+
+'Recurring Invoice Information' => 'Recurring Invoice Information',
+'Enable Recurring' => 'Enable Recurring',
+'Frequency' => 'Frequency',
+'Start Period' => 'Start Period',
+'End Period' => 'End Period',
+'Payment Duration' => 'Payment Duration',
+'Invoice Status' => 'Invoice Status',
+
 );
 
 ?>
