@@ -1,29 +1,39 @@
 <?php
-/*********************************************************************************
-** The contents of this file are subject to the vtiger CRM Public License Version 1.0
+/*+********************************************************************************
+ * The contents of this file are subject to the vtiger CRM Public License Version 1.0
  * ("License"); You may not use this file except in compliance with the License
  * The Original Code is:  vtiger CRM Open Source
  * The Initial Developer of the Original Code is vtiger.
  * Portions created by vtiger are Copyright (C) vtiger.
  * All Rights Reserved.
-*
  ********************************************************************************/
  
 require_once('include/CustomFieldUtil.php');
 require_once('Smarty_setup.php');
 
 
-global $mod_strings,$app_strings,$app_list_strings,$theme,$adb;
+global $mod_strings,$app_strings,$app_list_strings,$theme,$adb,$log;
 
 $theme_path="themes/".$theme."/";
-$image_path=$theme_path."images/";
+$image_path="themes/images/";
+
+$tabid=vtlib_purify($_REQUEST['tabid']);
+$fieldid=vtlib_purify($_REQUEST['fieldid']);
+
+// Set the tab type only during Custom Field creation for Calendar module based on the activity type
+if ($fieldid == '' && $_REQUEST['fld_module'] == 'Calendar' && isset($_REQUEST['activity_type'])) {
+	$activitytype = vtlib_purify($_REQUEST['activity_type']);
+	if ($activitytype == 'E') $tabid = '16';
+	if ($activitytype == 'T') $tabid = '9';
+}
+
+ $blockid = getBlockId($tabid,'LBL_CUSTOM_INFORMATION');
 
-$tabid=$_REQUEST['tabid'];
-$fieldid=$_REQUEST['fieldid'];
 if(isset($_REQUEST['uitype']) && $_REQUEST['uitype'] != '')
-	$uitype=$_REQUEST['uitype'];
+	$uitype=vtlib_purify($_REQUEST['uitype']);
 else
 	$uitype=1;
+
 $readonly = '';
 $smarty = new vtigerCRM_Smarty;
 $cfimagecombo = Array($image_path."text.gif",
@@ -38,7 +48,7 @@ $cfimagecombo = Array($image_path."text.gif",
                         $image_path."checkbox.gif",
                         $image_path."text.gif",
                         $image_path."cfpicklist.gif",
-			$image_path."skype.gif");
+						$image_path."skype.gif");
 
 $cftextcombo = Array($mod_strings['Text'],
                         $mod_strings['Number'],
@@ -52,8 +62,9 @@ $cftextcombo = Array($mod_strings['Text'],
                         $mod_strings['LBL_CHECK_BOX'],
                         $mod_strings['LBL_TEXT_AREA'],
                         $mod_strings['LBL_MULTISELECT_COMBO'],
-			$mod_strings['Skype']
+						$mod_strings['Skype']
 				);	
+				
 $typeVal = Array(
 	'0'=>'Text',
 	'1'=>'Number',
@@ -79,7 +90,7 @@ if(isset($fieldid) && $fieldid!='')
 	$readonly = "readonly";
 	if($fieldtype == '7' || $fieldtype == '11')
 	{
-		$query = "select * from vtiger_". mysql_real_escape_string($customfield_columnname);
+		$query = "select * from vtiger_". $adb->sql_escape_string($customfield_columnname);
 		$result = $adb->pquery($query, array());
 		$fldVal='';
 		while($row = $adb->fetch_array($result))
@@ -93,15 +104,16 @@ if(isset($fieldid) && $fieldid!='')
 }
 $smarty->assign("MOD", $mod_strings);
 $smarty->assign("APP", $app_strings);
-$smarty->assign("FLD_MODULE", $_REQUEST['fld_module']);
+$smarty->assign("THEME", $theme);
+$smarty->assign("FLD_MODULE", vtlib_purify($_REQUEST['fld_module']));
 if(isset($_REQUEST["duplicate"]) && $_REQUEST["duplicate"] == "yes")
 {
 	$error=$mod_strings['ERR_CUSTOM_FIELD_WITH_NAME']. $_REQUEST["fldlabel"] .$mod_strings['ERR_ALREADY_EXISTS'] . ' ' .$mod_strings['ERR_SPECIFY_DIFFERENT_LABEL'];
 	$smarty->assign("DUPLICATE_ERROR", $error);
-	$customfield_fieldlabel=$_REQUEST["fldlabel"];
-	$fieldlength=$_REQUEST["fldlength"];
-	$decimalvalue=$_REQUEST["flddecimal"];
-	$fldVal = $_REQUEST["fldPickList"];
+	$customfield_fieldlabel=vtlib_purify($_REQUEST["fldlabel"]);
+	$fieldlength=vtlib_purify($_REQUEST["fldlength"]);
+	$decimalvalue=vtlib_purify($_REQUEST["flddecimal"]);
+	$fldVal = vtlib_purify($_REQUEST["fldPickList"]);
 	$selectedvalue = $typeVal[$_REQUEST["fldType"]];
 }
 elseif($fieldid == '')
@@ -123,20 +135,22 @@ for($i=0;$i<count($cftextcombo);$i++)
                 $sel_val = 'selected';
         else
                 $sel_val = '';
-	$combo_output.= '<a href="javascript:void(0);" onClick="makeFieldSelected(this,'.$i.');" id="field'.$i.'" style="text-decoration:none;background-image:url('.$cfimagecombo[$i].');" class="customMnu" '.$disable_str.'>'.$cftextcombo[$i].'</a>';
+	$combo_output.= '<a href="javascript:void(0);" onClick="makeFieldSelected(this,'.$i.','.$blockid.');" id="field'.$i.'" style="text-decoration:none;background-image:url('.$cfimagecombo[$i].');" class="customMnu" '.$disable_str.'>'.$cftextcombo[$i].'</a>';
 
 }
-$output .= '<div id="orgLay" style="display:block;" class="layerPopup"><script language="JavaScript" type="text/javascript" src="include/js/customview.js"></script>
-	<form action="index.php" method="post" name="addtodb" onSubmit="return validate()">
-	  <input type="hidden" name="module" value="Settings">
-	  <input type="hidden" name="fld_module" value="'.$_REQUEST['fld_module'].'">
-	  <input type="hidden" name="parenttab" value="Settings">
-          <input type="hidden" name="action" value="AddCustomFieldToDB">
-	  <input type="hidden" name="fieldid" value="'.$fieldid.'">
-	  <input type="hidden" name="column" value="'.$customfield_columnname.'">
-	  <input type="hidden" name="mode" id="cfedit_mode" value="'.$mode.'">
-	  <input type="hidden" name="cfcombo" id="selectedfieldtype" value="">
-
+$output .= '<div id="customfield" style="display:block;" class="layerPopup"><script language="JavaScript" type="text/javascript" src="include/js/customview.js"></script>
+			<form action="index.php" method="post" name="addtodb" onSubmit="if(validate('.$blockid.')) {VtigerJS_DialogBox.block();}else{return false;}">
+	  		<input type="hidden" name="module" value="Settings">
+	  		<input type="hidden" name="fld_module" value="'.vtlib_purify($_REQUEST['fld_module']).'">
+	  		<input type="hidden" name="activity_type" value="'.$activitytype.'">
+	  		<input type="hidden" name="parenttab" value="Settings">
+      		<input type="hidden" name="action" value="AddCustomFieldToDB">
+		  	<input type="hidden" name="fieldid" value="'.$fieldid.'">
+	  		<input type="hidden" name="column" value="'.$customfield_columnname.'">
+	  		<input type="hidden" name="mode" id="cfedit_mode" value="'.$mode.'">
+	  		<input type="hidden" name="cfcombo" id="selectedfieldtype" value="">
+			<input type="hidden" name="blockid" value="'.$blockid.'">
+		
 	  
 		<table width="100%" border="0" cellpadding="5" cellspacing="0" class="layerHeadingULine">
 			<tr>';
@@ -145,7 +159,7 @@ $output .= '<div id="orgLay" style="display:block;" class="layerPopup"><script l
 			else
 				$output .= '<td width="60%" align="left" class="layerPopupHeading">'.$mod_strings['LBL_ADD_FIELD'].'</td>';
 				
-			$output .= '<td width="40%" align="right"><a href="javascript:fninvsh(\'orgLay\');"><img src="'.$image_path.'close.gif" border="0"  align="absmiddle" /></a></td>
+			$output .= '<td width="40%" align="right"><a href="javascript:fninvsh(\'customfield\');"><img src="'. vtiger_imageurl('close.gif', $theme).'" border="0"  align="absmiddle" /></a></td>
 			</tr>';
 			$output .='</table><table border=0 cellspacing=0 cellpadding=5 width=95% align=center> 
 							<tr>
@@ -165,54 +179,20 @@ $output .= '<div id="orgLay" style="display:block;" class="layerPopup"><script l
 					<table width="100%" border="0" cellpadding="5" cellspacing="0">
 						<tr>
 							<td class="dataLabel" nowrap="nowrap" align="right" width="30%"><b>'.$mod_strings['LBL_LABEL'].' </b></td>
-							<td align="left" width="70%"><input name="fldLabel" value="'.$customfield_fieldlabel.'" type="text" class="txtBox"></td>
+							<td align="left" width="70%"><input name="fldLabel_'.$blockid.'" id ="fldLabel_'.$blockid.'" value="'.$customfield_fieldlabel.'" type="text" class="txtBox"></td>
 						</tr>';
-					if($mode == 'edit')
-					{
-						switch($uitype)
-						{
-							case 1:
-								$output .= '<tr id="lengthdetails">
-									<td class="dataLabel" nowrap="nowrap" align="right"><b>'.$mod_strings['LBL_LENGTH'].'</b></td>
-									<td align="left"><input type="text" name="fldLength" value="'.$fieldlength.'" '.$readonly.' class="txtBox"></td>
-								</tr>';
-								break;
-							case 71:
-							case 7:
-								$output .= '<tr id="lengthdetails">
-									<td class="dataLabel" nowrap="nowrap" align="right"><b>'.$mod_strings['LBL_LENGTH'].'</b></td>
-									<td align="left"><input type="text" name="fldLength" value="'.$fieldlength.'" '.$readonly.' class="txtBox"></td>
-								</tr>';
-								$output .= '<tr id="decimaldetails">
-									<td class="dataLabel" nowrap="nowrap" align="right"><b>'.$mod_strings['LBL_DECIMAL_PLACES'].'</b></td>
-									<td align="left"><input type="text" name="fldDecimal" value="'.$decimalvalue.'" '.$readonly.' class="txtBox"></td>
-								</tr>';
-								break;
-							case 33:
-							case 15:
-								$output .= '<tr id="picklist">
-									<td class="dataLabel" nowrap="nowrap" align="right" valign="top"><b>'.$mod_strings['LBL_PICK_LIST_VALUES'].'</b></td>
-									<td align="left" valign="top"><textarea name="fldPickList" rows="10" class="txtBox" '.$readonly.'>'.$fldVal.'</textarea></td>
-									<!--td style="padding-left:10px"><img src="themes/Aqua/images/picklist_hint.gif"/></td-->
-								</tr>';
-								break;
-								
-						}
-					}
-					else
-					{
-						$output .= '<tr id="lengthdetails">
+					if($mode != 'edit') {
+						$output .= '<tr id="lengthdetails_'.$blockid.'">
 							<td class="dataLabel" nowrap="nowrap" align="right"><b>'.$mod_strings['LBL_LENGTH'].'</b></td>
-							<td align="left"><input type="text" name="fldLength" value="'.$fieldlength.'" '.$readonly.' class="txtBox"></td>
+							<td align="left"><input type="text" name="fldLength_'.$blockid.'" id= ="fldLength_'.$blockid.'" value="'.$fieldlength.'" '.$readonly.' class="txtBox"></td>
 						</tr>
-						<tr id="decimaldetails" style="visibility:hidden;">
+						<tr id="decimaldetails_'.$blockid.'" style="visibility:hidden;">
 							<td class="dataLabel" nowrap="nowrap" align="right"><b>'.$mod_strings['LBL_DECIMAL_PLACES'].'</b></td>
-							<td align="left"><input type="text" name="fldDecimal" value="'.$decimalvalue.'" '.$readonly.' class="txtBox"></td>
+							<td align="left"><input type="text" name="fldDecimal_'.$blockid.'" id= "fldDecimal_'.$blockid.'" value="'.$decimalvalue.'" '.$readonly.' class="txtBox"></td>
 						</tr>
-						<tr id="picklist" style="visibility:hidden;">
+						<tr id="picklistdetails_'.$blockid.'" style="visibility:hidden;">
 							<td class="dataLabel" nowrap="nowrap" align="right" valign="top"><b>'.$mod_strings['LBL_PICK_LIST_VALUES'].'</b></td>
-							<td align="left" valign="top"><textarea name="fldPickList" rows="10" class="txtBox" '.$readonly.'>'.$fldVal.'</textarea></td>
-							<!--td style="padding-left:10px"><img src="themes/Aqua/images/picklist_hint.gif"/></td-->
+							<td align="left" valign="top"><textarea name="fldPickList_'.$blockid.'"  id = ="fldPickList_'.$blockid.'" rows="10" class="txtBox" '.$readonly.'>'.$fldVal.'</textarea></td>
 						</tr>';
 					}
 				$output .= '	
@@ -227,11 +207,12 @@ $output .= '<div id="orgLay" style="display:block;" class="layerPopup"><script l
 			<tr>
 				<td align="center">
 					<input type="submit" name="save" value=" &nbsp; '.$app_strings['LBL_SAVE_BUTTON_LABEL'].' &nbsp; " class="crmButton small save" />&nbsp;
-					<input type="button" name="cancel" value=" '.$app_strings['LBL_CANCEL_BUTTON_LABEL'].' " class="crmButton small cancel" onclick="fninvsh(\'orgLay\');" />
+					<input type="button" name="cancel" value=" '.$app_strings['LBL_CANCEL_BUTTON_LABEL'].' " class="crmButton small cancel" onclick="fninvsh(\'customfield\');" />
 				</td>
 			</tr>
 	</table>
-		<input type="hidden" name="fieldType" id="fieldType" value="'.$selectedvalue.'">
+		<input type="hidden"  name="fieldType_'.$blockid.'" id="fieldType_'.$blockid.'" value="'.$selectedvalue.'">
+		<input type="hidden" name="selectedfieldtype_'.$blockid.'"id="selectedfieldtype_'.$blockid.'"value="">
 	</form></div>';
 echo $output;
-?>
+?>
\ No newline at end of file
