@@ -76,10 +76,10 @@ if($focus->is_authenticated())
 
 	// store the user's theme in the session
 	if (isset($_REQUEST['login_theme'])) {
-		$authenticated_user_theme = $_REQUEST['login_theme'];
+		$authenticated_user_theme = vtlib_purify($_REQUEST['login_theme']);
 	}
 	elseif (isset($_REQUEST['ck_login_theme']))  {
-		$authenticated_user_theme = $_REQUEST['ck_login_theme'];
+		$authenticated_user_theme = vtlib_purify($_REQUEST['ck_login_theme']);
 	}
 	else {
 		$authenticated_user_theme = $default_theme;
@@ -87,10 +87,10 @@ if($focus->is_authenticated())
 	
 	// store the user's language in the session
 	if (isset($_REQUEST['login_language'])) {
-		$authenticated_user_language = $_REQUEST['login_language'];
+		$authenticated_user_language = vtlib_purify($_REQUEST['login_language']);
 	}
 	elseif (isset($_REQUEST['ck_login_language']))  {
-		$authenticated_user_language = $_REQUEST['ck_login_language'];
+		$authenticated_user_language = vtlib_purify($_REQUEST['ck_login_language']);
 	}
 	else {
 		$authenticated_user_language = $default_language;
@@ -133,6 +133,16 @@ if($focus->is_authenticated())
 }
 else
 {
+	$sql = 'select user_name, id, crypt_type from vtiger_users where user_name=?';
+	$result = $adb->pquery($sql, array($focus->column_fields["user_name"]));
+	$rowList = $result->GetRows();
+	foreach ($rowList as $row) {
+		$cryptType = $row['crypt_type'];
+		if(strtolower($cryptType) == 'md5' && version_compare(PHP_VERSION, '5.3.0') >= 0) {
+			header("Location: modules/Migration/PHP5.3_PasswordHelp.php");
+			die;
+		}
+	}
 	$_SESSION['login_user_name'] = $focus->column_fields["user_name"];
 	$_SESSION['login_password'] = $user_password;
 	$_SESSION['login_error'] = $mod_strings['ERR_INVALID_PASSWORD'];
