@@ -197,6 +197,8 @@ $smarty->assign("BLOCKS", getBlocks($currentModule,"detail_view",'',$focus->colu
 $smarty->assign("USERNAME",$focus->last_name.' '.$focus->first_name);
 $smarty->assign("HOUR_FORMAT",$focus->hour_format);
 $smarty->assign("START_HOUR",$focus->start_hour);
+$_SESSION['Users_FORM_TOKEN'] = rand(5, 2000) * rand(2, 7);
+$smarty->assign('FORM_TOKEN', $_SESSION['Users_FORM_TOKEN']);
 
 //for check audittrail if it is enable or not
 $smarty->assign("AUDITTRAIL",$audit_trail);
