@@ -11,27 +11,46 @@
 require_once('include/logging.php');
 require_once('modules/Users/Users.php');
 require_once('include/database/PearDatabase.php');
-global $adb;
+global $adb ,$mod_strings ;
 
 $local_log =& LoggerManager::getLogger('UsersAjax');
 $ajaxaction = $_REQUEST["ajxaction"];
 if($ajaxaction == "DETAILVIEW")
 {
-	$crmid = $_REQUEST["recordid"];
+	if(empty($_SESSION['Users_FORM_TOKEN']) || $_SESSION['Users_FORM_TOKEN']
+			!== (int)$_REQUEST['form_token']) {
+		echo ":#:ERR".($app_strings['LBL_PERMISSION']);
+		die;
+	}
+	$userid = $_REQUEST["recordid"];
 	$tablename = $_REQUEST["tableName"];
 	$fieldname = $_REQUEST["fldName"];
 	$fieldvalue = utf8RawUrlDecode($_REQUEST["fieldValue"]); 
-	if($crmid != "")
+	if($userid != "")
 	{
 		$userObj = new Users();
-		$userObj->retrieve_entity_info($crmid,"Users");
+		$userObj->retrieve_entity_info($userid,"Users");
 		$userObj->column_fields[$fieldname] = $fieldvalue;
+
+                if($fieldname=='asterisk_extension'){
+			$query = "select 1 from vtiger_asteriskextensions
+                     inner join vtiger_users on vtiger_users.id=vtiger_asteriskextensions.userid
+                     where status='Active' and asterisk_extension =?";
+			$params = array($fieldvalue);
+			
+			$result = $adb->pquery($query, $params);
+		        if($adb->num_rows($result) > 0)
+			{
+				echo ":#:ERR".$mod_strings['LBL_ASTERISKEXTENSIONS_EXIST'];
+				return false;
+			}
+	     }
 		if($fieldname == 'internal_mailer'){
 			
 			if(isset($_SESSION['internal_mailer']) && $_SESSION['internal_mailer'] != $userObj->column_fields['internal_mailer'])
 				$_SESSION['internal_mailer'] = $userObj->column_fields['internal_mailer'];
 		}
-		$userObj->id = $crmid;
+		$userObj->id = $userid;
 		$userObj->mode = "edit";
 		$userObj->save("Users");
 		if($userObj->id != "")
@@ -46,4 +65,4 @@ if($ajaxaction == "DETAILVIEW")
 		echo ":#:FAILURE";
 	}
 }
-?>
\ No newline at end of file
+?>
