@@ -156,7 +156,7 @@ class Users {
 	var $record_id;
 	var $new_schema = true;
 
-	var $DEFAULT_PASSWORD_CRYPT_TYPE = 'MD5';
+	var $DEFAULT_PASSWORD_CRYPT_TYPE; //'BLOWFISH', /* before PHP5.3*/ MD5;
 
 	/** constructor function for the main user class
             instantiates the Logger class and PearDatabase Class	
@@ -167,6 +167,8 @@ class Users {
 		$this->log = LoggerManager::getLogger('user');
 		$this->log->debug("Entering Users() method ...");
 		$this->db = PearDatabase::getInstance();
+		$this->DEFAULT_PASSWORD_CRYPT_TYPE = (version_compare(PHP_VERSION, '5.3.0') >= 0)?
+				'PHP5.3MD5': 'MD5';
 		$this->log->debug("Exiting Users() method ...");
 	}
 
@@ -287,14 +289,17 @@ class Users {
 		// For more details on salt format look at: http://in.php.net/crypt
 		if($crypt_type == 'MD5') {
 			$salt = '$1$' . $salt . '$';
-		} else if($crypt_type == 'BLOWFISH') {
+		} elseif($crypt_type == 'BLOWFISH') {
 			$salt = '$2$' . $salt . '$';
+		} elseif($crypt_type == 'PHP5.3MD5') {
+			//only change salt for php 5.3 or higher version for backward
+			//compactibility.
+			//crypt API is lot stricter in taking the value for salt.
+			$salt = '$1$' . str_pad($salt, 9, '0');
 		}
 
-		$encrypted_password = crypt($user_password, $salt);	
-
+		$encrypted_password = crypt($user_password, $salt);
 		return $encrypted_password;
-
 	}
 
 	
@@ -468,7 +473,7 @@ class Users {
 	function get_user_crypt_type() {
 		
 		$crypt_res = null;
-		$crypt_type = '';
+		$crypt_type = $this->DEFAULT_PASSWORD_CRYPT_TYPE;
 
 		// For backward compatability, we need to make sure to handle this case.
 		global $adb;
@@ -488,7 +493,7 @@ class Users {
 			$crypt_type = $this->DEFAULT_PASSWORD_CRYPT_TYPE;
 		}
 
-		if($crypt_res) {
+		if($crypt_res && $this->db->num_rows($crypt_res)) {
 			$crypt_row = $this->db->fetchByAssoc($crypt_res);
 			$crypt_type = $crypt_row['crypt_type'];
 		}
@@ -715,6 +720,8 @@ class Users {
 		}
 		require_once('modules/Users/CreateUserPrivilegeFile.php');
 		createUserPrivilegesfile($this->id);
+		unset($_SESSION['next_reminder_interval']);
+		unset($_SESSION['next_reminder_time']);
 		if($insertion_mode != 'edit'){
 			$this->createAccessKey();
 		}
@@ -880,7 +887,14 @@ class Users {
 
 		}
 		else
-		{	
+		{
+			// Set the crypt_type being used, to override the DB default constraint as it is not in vtiger_field
+			if($table_name == 'vtiger_users' && strpos('crypt_type', $column) === false) {
+				$column .= ', crypt_type';
+				$qparams[]= $crypt_type;
+			}
+			// END
+
 			$sql1 = "insert into $table_name ($column) values(". generateQuestionMarks($qparams) .")";
 			$this->db->pquery($sql1, $qparams); 
 		}
@@ -1302,6 +1316,8 @@ class Users {
 	{
 		global $adb;
 		if($prev_reminder_interval != $this->column_fields['reminder_interval'] ){
+			unset($_SESSION['next_reminder_interval']);
+			unset($_SESSION['next_reminder_time']);
 			$set_reminder_next = date('Y-m-d H:i');
 			// NOTE date_entered has CURRENT_TIMESTAMP constraint, so we need to reset when updating the table
 			$adb->pquery("UPDATE vtiger_users SET reminder_next_time=?, date_entered=? WHERE id=?",array($set_reminder_next, $this->column_fields['date_entered'], $this->id));
@@ -1315,5 +1331,45 @@ class Users {
 	function filterInactiveFields($module) {
 		// TODO Nothing do right now
 	}
+	
+	function deleteImage() {
+		$sql1 = 'SELECT attachmentsid FROM vtiger_salesmanattachmentsrel WHERE smid = ?';
+		$res1 = $this->db->pquery($sql1, array($this->id));
+		if ($this->db->num_rows($res1) > 0) {
+			$attachmentId = $this->db->query_result($res1, 0, 'attachmentsid');
+			
+			$sql2 = "DELETE FROM vtiger_crmentity WHERE crmid=? AND setype='Users Attachments'";
+			$this->db->pquery($sql2, array($attachmentId));
+			
+			$sql3 = 'DELETE FROM vtiger_salesmanattachmentsrel WHERE smid=? AND attachmentsid=?';
+			$this->db->pquery($sql3, array($this->id, $attachmentId));			
+			
+			$sql2 = "UPDATE vtiger_users SET imagename='' WHERE id=?";
+			$this->db->pquery($sql2, array($this->id));
+			
+			$sql4 = 'DELETE FROM vtiger_attachments WHERE attachmentsid=?';
+			$this->db->pquery($sql4, array($attachmentId));			
+		}
+	}
+
+	/** Function to delete an entity with given Id */
+	function trash($module, $id) {
+		global $log, $current_user;
+
+		$this->mark_deleted($id);
+	}
+
+	/**
+	 * This function should be overridden in each module.  It marks an item as deleted.
+	 * @param <type> $id
+	 */
+	function mark_deleted($id) {
+		global $log, $current_user, $adb;
+		$date_var = date('Y-m-d H:i:s');
+		$query = "UPDATE vtiger_users set status=?,date_modified=?,modified_user_id=? where id=?";
+		$adb->pquery($query, array('Inactive', $adb->formatDate($date_var, true),
+			$current_user->id, $id), true,"Error marking record deleted: ");
+	}
+
 }
 ?>
\ No newline at end of file
