@@ -145,10 +145,29 @@ class Vtiger_PackageExport {
 	 * Export vtiger dependencies
 	 * @access private
 	 */
-	function export_Dependencies() {
-		global $vtiger_current_version;
+	function export_Dependencies($moduleInstance) {
+		global $vtiger_current_version, $adb;
+		$moduleid = $moduleInstance->id;
+		
+		$sqlresult = $adb->query("SELECT * FROM vtiger_tab_info WHERE tabid = $moduleid");
+		$vtigerMinVersion = $vtiger_current_version;
+		$vtigerMaxVersion = false;
+		$noOfPreferences = $adb->num_rows($sqlresult);
+		for($i=0; $i<$noOfPreferences; ++$i) {
+			$prefName = $adb->query_result($sqlresult,$i,'prefname');
+			$prefValue = $adb->query_result($sqlresult,$i,'prefvalue');
+			if($prefName == 'vtiger_min_version') {
+				$vtigerMinVersion = $prefValue;
+			}
+			if($prefName == 'vtiger_max_version') {
+				$vtigerMaxVersion = $prefValue;
+			}
+			
+		}
+		
 		$this->openNode('dependencies');
-		$this->outputNode($vtiger_current_version, 'vtiger_version');
+		$this->outputNode($vtigerMinVersion, 'vtiger_version');
+		if($vtigerMaxVersion !== false)	$this->outputNode($vtigerMaxVersion, 'vtiger_max_version');
 		$this->closeNode('dependencies');
 	}
 
@@ -188,7 +207,7 @@ class Vtiger_PackageExport {
 		}
 
 		// Export dependency information
-		$this->export_Dependencies();
+		$this->export_Dependencies($moduleInstance);
 
 		// Export module tables
 		$this->export_Tables($moduleInstance);
